Enum Mode
#[repr(u8)]pub enum Mode {
NormalExtBufen = 0,
NormalExtIntBufen = 1,
NormalExtBufdis = 2,
NormalIntBufdis = 3,
SampholdExtBufen = 4,
SampholdExtIntBufen = 5,
SampholdExtIntBufdis = 6,
SampholdIntBufdis = 7,
}Variants
NormalExtBufen = 0
Normal mode, external pin only, buffer enabled
NormalExtIntBufen = 1
Normal mode, external pin and internal peripherals, buffer enabled
NormalExtBufdis = 2
Normal mode, external pin only, buffer disabled
NormalIntBufdis = 3
Normal mode, internal peripherals only, buffer disabled
SampholdExtBufen = 4
Sample and hold mode, external pin only, buffer enabled
SampholdExtIntBufen = 5
Sample and hold mode, external pin and internal peripherals, buffer enabled
SampholdExtIntBufdis = 6
Sample and hold mode, external pin and internal peripherals, buffer disabled
SampholdIntBufdis = 7
Sample and hold mode, internal peripherals only, buffer disabled
Implementations